/*
 * Copyright (C) 2006-2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

using System;

using NUnit.Framework;

using DCSharp.Backend.Managers;
using DCSharp.Backend.Objects;

namespace DCSharp.Backend.Managers.Test
{
	[TestFixture()]
	public class SearchManagerTest
	{
		private SearchManager manager;
		private SearchInfo searchInfo;
		
		[SetUp]
		public void SetUp()
		{
			manager = new SearchManager(new HubManager());
			searchInfo = new SearchInfo("TTH");
		}
		
		[Test]
		public void Search()
		{
			manager.Search(searchInfo);
			manager.Search(searchInfo);
			
			Assert.IsTrue(manager.Contains(searchInfo));
		}
		
		[Test]
		[ExpectedException(typeof(ArgumentNullException))]
		public void SearchNull()
		{
			manager.Search(null);
		}
		
		[Test]
		public void StopSearch()
		{
			Search();
			
			manager.StopSearch(searchInfo);
			manager.StopSearch(searchInfo);
			
			Assert.IsFalse(manager.Contains(searchInfo));
		}
		
		[Test]
		[ExpectedException(typeof(ArgumentNullException))]
		public void StopSearchNull()
		{
			manager.StopSearch(null);
		}
		
		[Test]
		public void Contains()
		{
			Assert.IsFalse(manager.Contains(null));
		}
	}
}
