/*
 * Copyright (C) 2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

using System;
using System.Collections.Generic;
using System.IO;

using DCSharp.Backend.Connections;
using DCSharp.Backend.Objects;
using DCSharp.Xml;

namespace DCSharp.Backend.Managers
{
	public class UploadManager
	{
		private List<UserConnection> uploadConnections;
		
		public UploadManager(ConnectionManager connectionManager)
		{
			if (connectionManager == null)
			{
				throw new ArgumentNullException("connectionManager");
			}
			
			uploadConnections = new List<UserConnection>();
			
			// Events
			connectionManager.ConnectionRemoved += OnConnectionRemoved;
		}
		
		#region Properties
		
		public int ActiveUploads
		{
			get { return uploadConnections.Count; }
		}
		
		#endregion
		
		#region Methods
		
		public bool CanUpload(UserConnection connection, UploadFileInfo upload)
		{
			if (uploadConnections.Contains(connection))
			{
				return true;
			}
			
			// MiniSlots support
			if (upload.IsFileList || upload.Size < 16 * 1024)
			{
				return true;
			}
			
			lock (uploadConnections)
			{
				if (uploadConnections.Count >= Runtime.Settings.Slots)
				{
					return false;
				}
				
				// Has existing connection?
				foreach (UserConnection c in uploadConnections)
				{
					if (c.RemoteIdentity.User == connection.RemoteIdentity.User)
					{
						return false;
					}
				}
				
				uploadConnections.Add(connection);
				return true;
			}
		}
		
		private void OnConnectionRemoved(object obj, ConnectionEventArgs args)
		{
			UserConnection connection = (UserConnection)args.Connection;
			
			lock (uploadConnections)
			{
				uploadConnections.Remove(connection);
			}
		}
		
		#endregion
	}
}
