/*
 * Copyright (C) 2006-2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

using System;
using System.Xml.Serialization;

using DCSharp.Backend.Connections;

namespace DCSharp.Backend.Objects
{
	public class TransferEventArgs : EventArgs
	{
		public TransferEventArgs(TransferFileInfo transfer)
		{
			this.transfer = transfer;
		}
		
		public TransferFileInfo Transfer
		{
			get { return transfer; }
		}
		private TransferFileInfo transfer;
	}
	
	public class TransferFileInfo
	{
		public event EventHandler ActiveChanged;
		
		#region Constructors
		
		public TransferFileInfo(string name, long size, string tth) : this()
		{
			this.name = name;
			this.size = size;
			this.tth = tth;
		}
		
		public TransferFileInfo()
		{
		}
		
		#endregion
		
		#region Properties
		
		[XmlAttribute]
		public string Name
		{
			get { return name; }
			set { name = value; }
		}
		private string name;
		
		[XmlAttribute]
		public long Size
		{
			get { return size; }
			set { size = value; }
		}
		private long size;
		
		[XmlAttribute]
		public long Position
		{
			get { return position; }
			set { position = value; }
		}
		private long position;
		
		[XmlAttribute]
		public string TTH
		{
			get { return tth; }
			set { tth = value; }
		}
		private string tth;
		
		[XmlIgnore()]
		public bool IsFileList
		{
			get { return isFileList; }
			set { isFileList = value; }
		}
		private bool isFileList;
		
		[XmlIgnore()]
		public bool Active
		{
			get { return userConnection != null; }
		}
		
		[XmlIgnore()]
		public double Bps
		{
			get { return userConnection != null ? userConnection.Bps : 0; }
		}
		
		private UserConnection userConnection;
		
		[XmlIgnore()]
		public UserConnection UserConnection
		{
			get { return userConnection; }
			internal set
			{
				userConnection = value;
				OnActiveChanged();
			}
		}
		
		#endregion
		
		#region Methods
		
		public TimeSpan GetRemainingTime()
		{
			long remainingBytes = size - position;
			int remainingSeconds = 0;
			
			double bps = Bps;
			if (bps > 0)
			{
				remainingSeconds = (int)(remainingBytes / bps);
			}
			return TimeSpan.FromSeconds(remainingSeconds);
		}
		
		protected virtual void OnActiveChanged()
		{
			if (ActiveChanged != null)
			{
				ActiveChanged(this, EventArgs.Empty);
			}
		}
		
		#endregion
	}
}
