/* 
 * Copyright (C) 2004-2005 Jonathan Bindel
 * Copyright (C) 2006 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

using System.Collections.Generic;
using System.Xml.Serialization;

namespace DCSharp.Xml.FileList
{
	public class Directory
	{
		public Directory(string name) : this()
		{
			this.name = name;
		}
		
		public Directory()
		{
			directories = new List<Directory>();
			files = new List<File>();
		}
		
		#region Properties

		private string name;

		[XmlAttribute()]
		public string Name
		{
			get
			{
				return name;
			}
			set
			{
				name = value;
			}
		}

		private List<Directory> directories;
		
		[XmlElement("Directory")]
		public List<Directory> Directories
		{
			get
			{
				return directories;
			}
			set
			{
				directories = value;
			}
		}
		
		private List<File> files;
		
		[XmlElement("File")]
		public List<File> Files
		{
			get
			{
				return files;
			}
			set
			{
				files = value;
			}
		}

		#endregion

		#region Methods

		public long GetSize()
		{
			long total = 0;
			foreach(Directory directory in directories)
			{
				total += directory.GetSize();
			}
			foreach(File file in files)
			{
				total += file.Size;
			}
			return total;
		}
		
		#endregion
	}
}
